==> haskell-alsa-core-0.5.0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-core
version:              0.5.0.1
visibility:           public
id:                   alsa-core-0.5.0.1-21ZABdX9DCCCoc3hXQrDOJ
key:                  alsa-core-0.5.0.1-21ZABdX9DCCCoc3hXQrDOJ
license:              BSD-3-Clause
copyright:            Bjorn Bringert, Iavor S. Diatchki, Henning Thielemann
maintainer:           Henning Thielemann <alsa@henning-thielemann.de>
author:
    Henning Thielemann <alsa@henning-thielemann.de>, Bjorn Bringert <bjorn@bringert.net>, Iavor S. Diatchki <iavor.diatchki@gmail.com>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/ALSA
synopsis:             Binding to the ALSA Library API (Exceptions).
description:
    This package provides access to ALSA infrastructure,
    that is needed by both alsa-seq and alsa-pcm.

category:             Sound, Music
abi:                  4b7eb95bfcef4457a8787d7d73fe1a9e
exposed:              True
exposed-modules:      Sound.ALSA.Exception
import-dirs:          /usr/lib/ghc-8.10.5/site-local/alsa-core-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/alsa-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/alsa-core-0.5.0.1
hs-libraries:         HSalsa-core-0.5.0.1-21ZABdX9DCCCoc3hXQrDOJ
extra-libraries:      asound
depends:
    base-4.14.2.0 extensible-exceptions-0.1.1.4-9nRdO96RVgFCedKm18TbaI

haddock-interfaces:   /usr/share/doc/haskell-alsa-core/html/alsa-core.haddock
haddock-html:         /usr/share/doc/haskell-alsa-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-alsa-core-0.5.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-core
version:              0.5.0.1
visibility:           public
id:                   alsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
key:                  alsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
license:              BSD-3-Clause
copyright:            Bjorn Bringert, Iavor S. Diatchki, Henning Thielemann
maintainer:           Henning Thielemann <alsa@henning-thielemann.de>
author:
    Henning Thielemann <alsa@henning-thielemann.de>, Bjorn Bringert <bjorn@bringert.net>, Iavor S. Diatchki <iavor.diatchki@gmail.com>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/ALSA
synopsis:             Binding to the ALSA Library API (Exceptions).
description:
    This package provides access to ALSA infrastructure,
    that is needed by both alsa-seq and alsa-pcm.

category:             Sound, Music
abi:                  949539fdaa61cbc8b3148fdd3077bd09
exposed:              True
exposed-modules:      Sound.ALSA.Exception
import-dirs:          /usr/lib/ghc-9.0.2/site-local/alsa-core-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/alsa-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/alsa-core-0.5.0.1
hs-libraries:         HSalsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
extra-libraries:      asound
depends:
    base-4.15.1.0 extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA

haddock-interfaces:   /usr/share/doc/haskell-alsa-core/html/alsa-core.haddock
haddock-html:         /usr/share/doc/haskell-alsa-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
